=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2006-03-09 22:54:29 +0000
+++ bzrlib/conflicts.py	2006-03-10 06:20:13 +0000
@@ -31,7 +31,10 @@
 from bzrlib.option import Option
 from bzrlib.osutils import rename
 from bzrlib.rio import Stanza
-from bzrlib.workingtree import CONFLICT_SUFFIXES, WorkingTree
+
+
+CONFLICT_SUFFIXES = ('.THIS', '.BASE', '.OTHER')
+
 
 class cmd_conflicts(bzrlib.commands.Command):
     """List files with conflicts.
@@ -49,6 +52,7 @@
     See also bzr resolve.
     """
     def run(self):
+        from bzrlib.workingtree import WorkingTree
         for path in WorkingTree.open_containing(u'.')[0].iter_conflicts():
             print path
 
@@ -70,6 +74,7 @@
     takes_args = ['file*']
     takes_options = [Option('all', help='Resolve all conflicts in this tree')]
     def run(self, file_list=None, all=False):
+        from bzrlib.workingtree import WorkingTree
         if file_list is None:
             if not all:
                 raise BzrCommandError(

=== modified file 'bzrlib/tests/test_workingtree.py'
--- bzrlib/tests/test_workingtree.py	2006-03-09 05:11:24 +0000
+++ bzrlib/tests/test_workingtree.py	2006-03-10 06:20:13 +0000
@@ -200,3 +200,18 @@
         self.assertTrue(our_lock.peek())
         tree.unlock()
         self.assertEquals(our_lock.peek(), None)
+
+    def make_tree(self):
+        t = self.get_transport()
+        url = self.get_url()
+        dir = bzrdir.BzrDirMetaFormat1().initialize(url)
+        repo = dir.create_repository()
+        branch = dir.create_branch()
+        return workingtree.WorkingTreeFormat3().initialize(dir)
+
+    def test_conflicts(self):
+        from bzrlib.tests.test_conflicts import example_conflicts
+        tree = self.make_tree()
+        tree.set_conflict_lines(example_conflicts)
+        tree2 = WorkingTree.open('.')
+        self.assertEqual(list(tree2.conflict_lines()), example_conflicts)

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2006-03-09 19:41:48 +0000
+++ bzrlib/workingtree.py	2006-03-10 06:20:13 +0000
@@ -30,6 +30,7 @@
 """
 
 MERGE_MODIFIED_HEADER_1 = "BZR merge-modified list format 1"
+CONFLICT_HEADER_1 = "BZR conflict list format 1"
 
 # TODO: Give the workingtree sole responsibility for the working inventory;
 # remove the variable and references to it from the branch.  This may require
@@ -49,6 +50,8 @@
 from bzrlib.atomicfile import AtomicFile
 from bzrlib.branch import (Branch,
                            quotefn)
+from bzrlib.conflicts import (stanza_conflicts, conflict_stanzas,
+                              CONFLICT_SUFFIXES)
 import bzrlib.bzrdir as bzrdir
 from bzrlib.decorators import needs_read_lock, needs_write_lock
 import bzrlib.errors as errors
@@ -1300,8 +1303,24 @@
             self._control_files.put_utf8('last-revision', revision_id)
             return True
 
-
-CONFLICT_SUFFIXES = ('.THIS', '.BASE', '.OTHER')
+    @needs_write_lock
+    def set_conflict_lines(self, lines):
+        self._put_rio('conflicts', conflict_stanzas(lines), CONFLICT_HEADER_1)
+
+    @needs_read_lock
+    def conflict_lines(self):
+        try:
+            confile = self._control_files.get('conflicts')
+        except NoSuchFile:
+            return []
+        try:
+            if confile.next() != CONFLICT_HEADER_1 + '\n':
+                raise ConflictFormatError()
+        except StopIteration:
+            raise ConflictFormatError()
+        return stanza_conflicts(RioReader(confile))
+
+
 def get_conflicted_stem(path):
     for suffix in CONFLICT_SUFFIXES:
         if path.endswith(suffix):

